@@ -54,6 +54,7 @@ enum dm_dev_type {
     DM_BRIDGE,
     DM_QSFP_CABLE,
     DM_SFP_CABLE,
+    DM_LINKX // linkx chip
 };
 
 struct device_info {
@@ -71,6 +72,14 @@ struct device_info {
 #define SFP_DIGITAL_DIAGNOSTIC_MONITORING_IMPLEMENTED_ADDR     92
 #define SFP_PAGING_IMPLEMENTED_INDICATOR_ADDR                  64
 
+#define ARDBEG_REV0_DEVID 0x6e
+#define ARDBEG_REV1_DEVID 0x7e
+#define ARDBEG_MIRRORED_DEVID 0x70
+#define BARITONE_DEVID 0x6b
+#define BARITONE_MIRRORED_DEVID 0x71
+#define MENHIT_DEVID 0x6f
+
+
 #ifdef CABLES_SUPP
 enum dm_dev_type getCableType(u_int8_t id)
 {
@@ -199,6 +208,24 @@ static struct device_info g_devs_info[] = {
         2,                      //port_num
         DM_HCA                  //dev_type
     },
+    {
+        DeviceConnectX6DX,      //dm_id
+        0x212,                  //hw_dev_i
+        -1,                     //hw_rev_i
+        -1,                     //sw_dev_i
+        "ConnectX6DX",          //name
+        2,                      //port_num
+        DM_HCA                  //dev_type
+    },
+    {
+        DeviceConnectX6LX,      //dm_id
+        0x216,                  //hw_dev_i
+        -1,                     //hw_rev_i
+        -1,                     //sw_dev_i
+        "ConnectX6LX",          //name
+        2,                      //port_num
+        DM_HCA                  //dev_type
+    },
     {
         DeviceBlueField,        //dm_id
         0x211,                  //hw_dev_i
@@ -208,6 +235,15 @@ static struct device_info g_devs_info[] = {
         2,                      //port_num
         DM_HCA                  //dev_type
     },
+    {
+        DeviceBlueField2,        //dm_id
+        0x214,                  //hw_dev_i
+        -1,                     //hw_rev_i
+        -1,                     //sw_dev_i
+        "BlueField2",            //name
+        2,                      //port_num
+        DM_HCA                  //dev_type
+    },
     {
         DeviceFPGANewton,       //dm_id
         0xfff,                  //hw_dev_i - Dummy device ID till we have official one
@@ -298,6 +334,33 @@ static struct device_info g_devs_info[] = {
         80,                     //port_num
         DM_SWITCH               //dev_type
     },
+    {
+        DeviceArdbeg,           //dm_id
+        0x6e,                   //hw_dev_i (ArdbegMirror 0x70)
+        -1,                     //hw_rev_i
+        -1,                     //sw_dev_i
+        "Ardbeg",               //name
+        -1,                     //port_num
+        DM_LINKX                //dev_type
+    },
+        {
+        DeviceBaritone,         //dm_id
+        0x6b,                   //hw_dev_i (BaritoneMirror 0x71)
+        -1,                     //hw_rev_i
+        -1,                     //sw_dev_i
+        "Baritone",             //name
+        -1,                     //port_num
+        DM_LINKX                //dev_type
+    },
+    {
+        DeviceMenhit,           //dm_id
+        0x6f,                   //hw_dev_i
+        -1,                     //hw_rev_i
+        -1,                     //sw_dev_i
+        "Menhit",               //name
+        -1,                     //port_num
+        DM_LINKX                //dev_type
+    },
     {
         DeviceSecureHost,       //dm_id
         0xcafe,                 //hw_dev_i
@@ -307,6 +370,15 @@ static struct device_info g_devs_info[] = {
         -1,                     //port_num
         DM_UNKNOWN              //dev_type
     },
+    {
+        DeviceSpectrum3,        //dm_id
+        0x250,                  //hw_dev_i
+        -1,                     //hw_rev_i
+        -1,                     //sw_dev_i
+        "Spectrum3",            //name
+        128,                    //port_num NEED_CHECK
+        DM_SWITCH               //dev_type
+    },
     {
         DeviceUnknown,          //dm_id
         0,                      //hw_dev_i
@@ -365,13 +437,37 @@ int dm_get_device_id(mfile *mf,
     }
 #endif
 #ifdef CABLES_SUPP
+    if (mf->tp == MST_LINKX_CHIP){
+ 
+        switch (mf->linkx_chip_devid){
+            case ARDBEG_REV0_DEVID:
+            case ARDBEG_REV1_DEVID:
+            case ARDBEG_MIRRORED_DEVID:
+                *ptr_dm_dev_id = DeviceArdbeg;
+                break;
+            case BARITONE_DEVID:
+            case BARITONE_MIRRORED_DEVID:
+                *ptr_dm_dev_id = DeviceBaritone;
+                break;
+            case MENHIT_DEVID:
+                *ptr_dm_dev_id = DeviceMenhit;
+                break;
+            default:
+                return 1;
+                break;
+        }
+        *ptr_hw_dev_id = (u_int32_t)mf->linkx_chip_devid;
+        return 0;
+
+    }
+
     if (mf->tp == MST_CABLE) {
         //printf("-D- Getting cable ID\n");
         if (mread4(mf, CABLEID_ADDR, &dword) != 4) {
             //printf("FATAL - crspace read (0x%x) failed: %s\n", DEVID_ADDR, strerror(errno));
             return 1;
         }
-        dword = __cpu_to_le32(dword); // Cable pages are in LE
+        //dword = __cpu_to_le32(dword); // Cable pages are read in LE, no need to swap
         *ptr_hw_dev_id = 0xffff;
         u_int8_t id = EXTRACT(dword, 0, 8);
         enum dm_dev_type cbl_type = getCableType(id);
@@ -418,7 +514,7 @@ int dm_get_device_id(mfile *mf,
     // Special case for MLNX OS getting dev_id using REG MGIR
     if (dev_flags & MDEVS_MLNX_OS) {
         reg_access_status_t rc;
-        struct tools_open_mgir mgir;
+        struct reg_access_hca_mgir mgir;
         memset(&mgir, 0, sizeof(mgir));
         rc = reg_access_mgir(mf, REG_ACCESS_METHOD_GET, &mgir);
         //printf("-D- RC[%s] -- REVID: %d -- DEVID: %d hw_dev_id: %d\n", m_err2str(rc), mgir.HWInfo.REVID, mgir.HWInfo.DEVID, mgir.HWInfo.hw_dev_id);
@@ -496,11 +592,21 @@ int dm_dev_is_hca(dm_dev_id_t type)
     return get_entry(type)->dev_type == DM_HCA;
 }
 
+int dm_dev_is_200g_speed_supported_hca(dm_dev_id_t type)
+{
+    return (dm_dev_is_hca(type) && (get_entry(type)->hw_dev_id >= get_entry(DeviceConnectX6)->hw_dev_id));
+}
+
 int dm_dev_is_switch(dm_dev_id_t type)
 {
     return get_entry(type)->dev_type == DM_SWITCH;
 }
 
+int dm_dev_is_200g_speed_supported_switch(dm_dev_id_t type)
+{
+    return (dm_dev_is_switch(type) && (get_entry(type)->hw_dev_id >= get_entry(DeviceQuantum)->hw_dev_id));
+}
+
 int dm_dev_is_bridge(dm_dev_id_t type)
 {
     return get_entry(type)->dev_type == DM_BRIDGE;
@@ -523,18 +629,9 @@ u_int32_t dm_get_hw_rev_id(dm_dev_id_t type)
 
 int dm_is_fpp_supported(dm_dev_id_t type)
 {
+    // Function per port is supported only in HCAs that arrived after CX3
     const struct device_info *dp = get_entry(type);
-    if (
-        dp->dm_id == DeviceConnectIB   ||
-        dp->dm_id == DeviceConnectX4   ||
-        dp->dm_id == DeviceConnectX4LX ||
-        dp->dm_id == DeviceConnectX5   ||
-        dp->dm_id == DeviceConnectX6   ||
-        dp->dm_id == DeviceBlueField) {
-        return 1;
-    } else {
-        return 0;
-    }
+    return (dm_is_5th_gen_hca(dp->dm_id) || dm_is_newton(dp->dm_id));
 }
 
 int dm_is_device_supported(dm_dev_id_t type)
@@ -557,10 +654,7 @@ int dm_is_livefish_mode(mfile *mf)
     }
     u_int32_t swid = mf->dinfo->pci.dev_id;
     //printf("-D- swid: %#x, devid: %#x\n", swid, devid);
-    if (devid_t == DeviceConnectX2    ||
-        devid_t == DeviceConnectX3    ||
-        devid_t == DeviceConnectX3Pro ||
-        devid_t == DeviceSwitchX) {
+    if (dm_is_4th_gen(devid_t) || dm_is_switchx(devid_t)) {
         return (devid == swid - 1);
     } else {
         return (devid == swid);
@@ -569,3 +663,39 @@ int dm_is_livefish_mode(mfile *mf)
     return 0;
 }
 
+int dm_is_4th_gen(dm_dev_id_t type)
+{
+    return (type == DeviceConnectX2 ||
+            type == DeviceConnectX3 ||
+            type == DeviceConnectX3Pro);
+}
+
+int dm_is_5th_gen_hca(dm_dev_id_t type)
+{
+    return (dm_dev_is_hca(type) && !dm_is_4th_gen(type));
+}
+
+int dm_is_newton(dm_dev_id_t type)
+{
+    return (type == DeviceFPGANewton);
+}
+
+int dm_is_connectib(dm_dev_id_t type)
+{
+    return (type == DeviceConnectIB);
+}
+
+int dm_is_switchx(dm_dev_id_t type)
+{
+    return (type == DeviceSwitchX);
+}
+
+int dm_is_new_gen_switch(dm_dev_id_t type)
+{
+    return (dm_dev_is_switch(type) && !dm_is_switchx(type));
+}
+
+int dm_dev_is_raven_family_switch(dm_dev_id_t type)
+{
+    return (dm_dev_is_switch(type) && (type == DeviceQuantum || type == DeviceSpectrum2 || type == DeviceSpectrum3));
+}
