@@ -96,6 +96,7 @@ enum dm_dev_id
     DeviceDummy,
     DeviceSecureHost,
     DeviceConnectX6DX,
+    DeviceConnectX6LX,
     DeviceSpectrum3, //Firebird
     DeviceEndMarker           // Dummy Device - Marker for indicating end of devices when iterating
 };
@@ -197,6 +198,7 @@ int dm_is_switchx(dm_dev_id_t type);
 
 int dm_is_new_gen_switch(dm_dev_id_t type);
 
+int dm_dev_is_raven_family_switch(dm_dev_id_t type);
 /*
  * A predicate returning if the device is in LiveFish mode
  */
