@@ -1,3 +1,35 @@
+#copyright (c) 2004-2020 Mellanox Technologies LTD. All rights reserved.   
+#                                                                           
+# This software is available to you under a choice of one of two            
+# licenses.  You may choose to be licensed under the terms of the GNU       
+# General Public License (GPL) Version 2, available from the file           
+# COPYING in the main directory of this source tree, or the                 
+# OpenIB.org BSD license below:                                             
+#                                                                           
+#     Redistribution and use in source and binary forms, with or            
+#     without modification, are permitted provided that the following       
+#     conditions are met:                                                   
+#                                                                           
+#      - Redistributions of source code must retain the above               
+#        copyright notice, this list of conditions and the following        
+#        disclaimer.                                                        
+#                                                                           
+#      - Redistributions in binary form must reproduce the above            
+#        copyright notice, this list of conditions and the following        
+#        disclaimer in the documentation and/or other materials             
+#        provided with the distribution.                                    
+#                                                                           
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,         
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE OF                   
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND                     
+# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS       
+# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN        
+# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN         
+# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE          
+# SOFTWARE.                                                                 
+#--                                                                         
+
+
 from __future__ import print_function
 
 import argparse
@@ -70,6 +102,7 @@ class PrivilegeMgr(object):
     CONFIG_CMD_LINE = "mstconfig -d %s -f %s --yes set_raw"
     MCRA_CMD_LINE = "mstmcra %s 0xf0014.0:16"
     BLUE_FIELD_DEV_ID = 0x211
+    BLUE_FIELD2_DEV_ID = 0x214
     TITLE = "MLNX_RAW_TLV_FILE\n"
     RAW_BYTES = "0x03000204 0x07000083 0x00000000"
 
@@ -131,7 +164,11 @@ class PrivilegeMgr(object):
 
         if exit_code != 0:
             print("Failed")
-            print(stdout + stderr)
+            if (self._privilege):
+                error(
+                    "Removing the restriction only effective on the ARM side")
+            else:
+                error("The host is already restricted!")
         else:
             print("Done!")
         return exit_code
@@ -148,7 +185,7 @@ class PrivilegeMgr(object):
         if exit_code != 0:
             raise PrivilegeException("Unknown device '%s'!" % self._device)
         dev_id = int(stdout, 16)
-        if dev_id != self.BLUE_FIELD_DEV_ID:
+        if dev_id not in (self.BLUE_FIELD_DEV_ID, self.BLUE_FIELD2_DEV_ID):
             raise PrivilegeException(
                 "Device '%s' is not supported, "
                 "only BlueField devices are supported!" % self._device)
