@@ -312,7 +312,7 @@ int mtcr_check_signature(mfile *mf)
                 if (mst_driver_connectx_flush(mf)) {
                     return -1;
                 }
-            } else if (mtcr_connectx_flush(mf->ptr, ctx->fdlock)) {
+            } else if (mtcr_connectx_flush(mf->bar_virtual_addr, ctx->fdlock)) {
                 return -1;
             }
         }
@@ -468,8 +468,8 @@ static
 int mtcr_pcicr_mclose(mfile *mf)
 {
     if (mf) {
-        if (mf->ptr) {
-            munmap(mf->ptr, MTCR_MAP_SIZE);
+        if (mf->bar_virtual_addr) {
+            munmap(mf->bar_virtual_addr, MTCR_MAP_SIZE);
         }
         if (mf->fd > 0) {
             close(mf->fd);
@@ -497,9 +497,9 @@ int mtcr_mmap(mfile *mf, const char *name, off_t off, int ioctl_needed)
         return -1;
     }
 
-    mf->ptr = mmap(NULL, MTCR_MAP_SIZE, PROT_READ | PROT_WRITE, MAP_SHARED, mf->fd, off);
+    mf->bar_virtual_addr = mmap(NULL, MTCR_MAP_SIZE, PROT_READ | PROT_WRITE, MAP_SHARED, mf->fd, off);
 
-    if (!mf->ptr || mf->ptr == MAP_FAILED) {
+    if (!mf->bar_virtual_addr || mf->bar_virtual_addr == MAP_FAILED) {
         err = errno;
         close(mf->fd);
         errno = err;
@@ -517,12 +517,12 @@ int mtcr_pcicr_mread4(mfile *mf, unsigned int offset, u_int32_t *value)
         return 0;
     }
     if (ctx->need_flush) {
-        if (mtcr_connectx_flush(mf->ptr, ctx->fdlock)) {
+        if (mtcr_connectx_flush(mf->bar_virtual_addr, ctx->fdlock)) {
             return 0;
         }
         ctx->need_flush = 0;
     }
-    u_int32_t tmp = ((u_int32_t*)mf->ptr)[offset / 4];
+    u_int32_t tmp = ((u_int32_t*)mf->bar_virtual_addr)[offset / 4];
     *value = __be32_to_cpu(tmp);
     return 4;
 }
@@ -535,7 +535,7 @@ int mtcr_pcicr_mwrite4(mfile *mf, unsigned int offset, u_int32_t value)
         errno = EINVAL;
         return 0;
     }
-    *((u_int32_t*) ((char*) mf->ptr + offset)) = __cpu_to_be32(value);
+    *((u_int32_t*) ((char*) mf->bar_virtual_addr + offset)) = __cpu_to_be32(value);
     ctx->need_flush = ctx->connectx_flush;
     return 4;
 }
@@ -554,7 +554,7 @@ int mtcr_pcicr_open(mfile *mf, const char *name, char *conf_name, off_t off, int
     ctx->mwrite4_block = mwrite_chunk_as_multi_mwrite4;
     ctx->mclose = mtcr_pcicr_mclose;
 
-    mf->ptr = NULL;
+    mf->bar_virtual_addr = NULL;
     mf->fd = -1;
     ctx->connectx_flush = 0;
     ctx->need_flush = 0;
@@ -589,6 +589,8 @@ end:
     return rc;
 }
 
+
+
 //
 // PCI CONF ACCESS FUNCTIONS
 //
@@ -794,7 +796,7 @@ static int driver_mwrite4_block(mfile *mf, unsigned int offset, u_int32_t *data,
                 return -1;
             }
             offset += towrite;
-            dest_ptr += towrite;
+            dest_ptr += towrite / sizeof(u_int32_t);
         }
         return length;
     } else {
@@ -822,7 +824,7 @@ static int driver_mread4_block(mfile *mf, unsigned int offset, u_int32_t *data,
             }
             memcpy(dest_ptr, read4_buf.data, toread);
             offset += toread;
-            dest_ptr += toread;
+            dest_ptr += toread / sizeof(u_int32_t);
         }
         return length;
     } else {
@@ -834,8 +836,8 @@ static
 int mtcr_driver_mclose(mfile *mf)
 {
     if (mf) {
-        if (mf->ptr) {
-            munmap(mf->ptr, MTCR_MAP_SIZE);
+        if (mf->bar_virtual_addr) {
+            munmap(mf->bar_virtual_addr, MTCR_MAP_SIZE);
         }
         if (mf->fd > 0) {
             close(mf->fd);
@@ -876,7 +878,7 @@ int mtcr_driver_open(mfile *mf, MType dev_type,
         ctx->mread4_block  = driver_mread4_block;
         ctx->mwrite4_block = driver_mwrite4_block;
         ctx->mclose        = mtcr_driver_mclose;
-        mf->ptr            = NULL;
+        mf->bar_virtual_addr            = NULL;
         unsigned int slot_num;
         rc = ioctl(mf->fd, PCI_CONNECTX_WA, &slot_num);
         if (rc < 0) {
@@ -1618,12 +1620,17 @@ static long supported_dev_ids[] = {
     0x1017,     //Connect-X5
     0x1019,     //Connect-X5Ex
     0x101b,     //Connect-X6
+    0x101d,     //Connect-X6DX
+    0x101f,     //Connect-X6LX
     0xc738,     //SwitchX
     0xcb20,     //Switch-IB
     0xcb84,     //Spectrum
     0xcf08,     //Switch-IB2
     0xd2f0,     //Quantum
+    0xcf6c,     //Spectrum2
     0xa2d2,     //MT416842 Family BlueField integrated ConnectX-5 network controller
+    0xa2d6,     //MT416846 Family BlueField2 integrated ConnectX-6DX network controller
+    0xcf70,     //Spectrum3
     -1
 };
 
@@ -1633,6 +1640,7 @@ static long live_fish_id_database[] = {
     0x249,
     0x24b,
     0x24d,
+    0x24e,
     0x1F6,
     0x1F8,
     0x1FF,
@@ -1642,6 +1650,9 @@ static long live_fish_id_database[] = {
     0x20d,
     0x20f,
     0x211,
+    0x212, //Connect-X6DX
+    0x216, //Connect-X6LX
+    0x250, //Spectrum3
     -1
 };
 
@@ -2910,7 +2921,7 @@ static int mreg_send_raw(mfile *mf, u_int16_t reg_id, maccess_reg_method_t metho
     memcpy(reg_data, buffer + OP_TLV_SIZE + REG_TLV_HEADER_LEN, reg_size);
 
 #ifdef _ENABLE_DEBUG_
-    fprintf(stdout, "-I-Tlv's of Data Recieved:\n");
+    fprintf(stdout, "-I-Tlv's of Data Received:\n");
     fprintf(stdout, "\tOperation Tlv\n");
     OperationTlv_dump(&tlv, stdout);
     fprintf(stdout, "\tReg Tlv\n");
@@ -3274,3 +3285,10 @@ const char* m_err2str(MError status)
         return "Unknown error code";
     }
 }
+
+int allocate_kernel_memory_page(mfile* f, mtcr_alloc_page* page)
+{
+    (void)f;
+    (void)page;
+    return -1;//unsupported
+}
