@@ -141,6 +141,11 @@ static struct device_sem_info g_dev_sem_info_db[] = {
         {0xe74e0},               // hw_sem_addr
         1,                       // vsec_sem_supported
     },
+    {
+        DeviceBlueField2,        // dev_id
+        {0xe74e0},               // hw_sem_addr
+        1,                       // vsec_sem_supported
+    },
     {
         DeviceQuantum,          // dev_id
         {0xa68f8},               // hw_sem_addr
@@ -161,6 +166,16 @@ static struct device_sem_info g_dev_sem_info_db[] = {
         {0xe74e0},               // hw_sem_addr
         1,                       // vsec_sem_supported
     },
+    {
+        DeviceConnectX6LX,       // dev_id
+        {0xe74e0},               // hw_sem_addr
+        1,                       // vsec_sem_supported
+    },
+    {
+        DeviceSpectrum3,          // dev_id
+        {0xa68f8},               // hw_sem_addr
+        0,                       // vsec_sem_supported
+    }
 };
 
 #define MAX_SEMAPHORE_ADDRES 8
